Documentation
¶
Index ¶
- type CephBlockPoolLister
- type CephBlockPoolListerExpansion
- type CephBlockPoolNamespaceLister
- type CephBlockPoolNamespaceListerExpansion
- type CephClientLister
- type CephClientListerExpansion
- type CephClientNamespaceLister
- type CephClientNamespaceListerExpansion
- type CephClusterLister
- type CephClusterListerExpansion
- type CephClusterNamespaceLister
- type CephClusterNamespaceListerExpansion
- type CephFilesystemLister
- type CephFilesystemListerExpansion
- type CephFilesystemNamespaceLister
- type CephFilesystemNamespaceListerExpansion
- type CephNFSLister
- type CephNFSListerExpansion
- type CephNFSNamespaceLister
- type CephNFSNamespaceListerExpansion
- type CephObjectStoreLister
- type CephObjectStoreListerExpansion
- type CephObjectStoreNamespaceLister
- type CephObjectStoreNamespaceListerExpansion
- type CephObjectStoreUserLister
- type CephObjectStoreUserListerExpansion
- type CephObjectStoreUserNamespaceLister
- type CephObjectStoreUserNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CephBlockPoolLister ¶
type CephBlockPoolLister interface {
// List lists all CephBlockPools in the indexer.
List(selector labels.Selector) (ret []*v1.CephBlockPool, err error)
// CephBlockPools returns an object that can list and get CephBlockPools.
CephBlockPools(namespace string) CephBlockPoolNamespaceLister
CephBlockPoolListerExpansion
}
CephBlockPoolLister helps list CephBlockPools.
func NewCephBlockPoolLister ¶
func NewCephBlockPoolLister(indexer cache.Indexer) CephBlockPoolLister
NewCephBlockPoolLister returns a new CephBlockPoolLister.
type CephBlockPoolListerExpansion ¶
type CephBlockPoolListerExpansion interface{}
CephBlockPoolListerExpansion allows custom methods to be added to CephBlockPoolLister.
type CephBlockPoolNamespaceLister ¶
type CephBlockPoolNamespaceLister interface {
// List lists all CephBlockPools in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephBlockPool, err error)
// Get retrieves the CephBlockPool from the indexer for a given namespace and name.
Get(name string) (*v1.CephBlockPool, error)
CephBlockPoolNamespaceListerExpansion
}
CephBlockPoolNamespaceLister helps list and get CephBlockPools.
type CephBlockPoolNamespaceListerExpansion ¶
type CephBlockPoolNamespaceListerExpansion interface{}
CephBlockPoolNamespaceListerExpansion allows custom methods to be added to CephBlockPoolNamespaceLister.
type CephClientLister ¶ added in v1.2.0
type CephClientLister interface {
// List lists all CephClients in the indexer.
List(selector labels.Selector) (ret []*v1.CephClient, err error)
// CephClients returns an object that can list and get CephClients.
CephClients(namespace string) CephClientNamespaceLister
CephClientListerExpansion
}
CephClientLister helps list CephClients.
func NewCephClientLister ¶ added in v1.2.0
func NewCephClientLister(indexer cache.Indexer) CephClientLister
NewCephClientLister returns a new CephClientLister.
type CephClientListerExpansion ¶ added in v1.2.0
type CephClientListerExpansion interface{}
CephClientListerExpansion allows custom methods to be added to CephClientLister.
type CephClientNamespaceLister ¶ added in v1.2.0
type CephClientNamespaceLister interface {
// List lists all CephClients in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephClient, err error)
// Get retrieves the CephClient from the indexer for a given namespace and name.
Get(name string) (*v1.CephClient, error)
CephClientNamespaceListerExpansion
}
CephClientNamespaceLister helps list and get CephClients.
type CephClientNamespaceListerExpansion ¶ added in v1.2.0
type CephClientNamespaceListerExpansion interface{}
CephClientNamespaceListerExpansion allows custom methods to be added to CephClientNamespaceLister.
type CephClusterLister ¶
type CephClusterLister interface {
// List lists all CephClusters in the indexer.
List(selector labels.Selector) (ret []*v1.CephCluster, err error)
// CephClusters returns an object that can list and get CephClusters.
CephClusters(namespace string) CephClusterNamespaceLister
CephClusterListerExpansion
}
CephClusterLister helps list CephClusters.
func NewCephClusterLister ¶
func NewCephClusterLister(indexer cache.Indexer) CephClusterLister
NewCephClusterLister returns a new CephClusterLister.
type CephClusterListerExpansion ¶
type CephClusterListerExpansion interface{}
CephClusterListerExpansion allows custom methods to be added to CephClusterLister.
type CephClusterNamespaceLister ¶
type CephClusterNamespaceLister interface {
// List lists all CephClusters in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephCluster, err error)
// Get retrieves the CephCluster from the indexer for a given namespace and name.
Get(name string) (*v1.CephCluster, error)
CephClusterNamespaceListerExpansion
}
CephClusterNamespaceLister helps list and get CephClusters.
type CephClusterNamespaceListerExpansion ¶
type CephClusterNamespaceListerExpansion interface{}
CephClusterNamespaceListerExpansion allows custom methods to be added to CephClusterNamespaceLister.
type CephFilesystemLister ¶
type CephFilesystemLister interface {
// List lists all CephFilesystems in the indexer.
List(selector labels.Selector) (ret []*v1.CephFilesystem, err error)
// CephFilesystems returns an object that can list and get CephFilesystems.
CephFilesystems(namespace string) CephFilesystemNamespaceLister
CephFilesystemListerExpansion
}
CephFilesystemLister helps list CephFilesystems.
func NewCephFilesystemLister ¶
func NewCephFilesystemLister(indexer cache.Indexer) CephFilesystemLister
NewCephFilesystemLister returns a new CephFilesystemLister.
type CephFilesystemListerExpansion ¶
type CephFilesystemListerExpansion interface{}
CephFilesystemListerExpansion allows custom methods to be added to CephFilesystemLister.
type CephFilesystemNamespaceLister ¶
type CephFilesystemNamespaceLister interface {
// List lists all CephFilesystems in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephFilesystem, err error)
// Get retrieves the CephFilesystem from the indexer for a given namespace and name.
Get(name string) (*v1.CephFilesystem, error)
CephFilesystemNamespaceListerExpansion
}
CephFilesystemNamespaceLister helps list and get CephFilesystems.
type CephFilesystemNamespaceListerExpansion ¶
type CephFilesystemNamespaceListerExpansion interface{}
CephFilesystemNamespaceListerExpansion allows custom methods to be added to CephFilesystemNamespaceLister.
type CephNFSLister ¶ added in v1.0.0
type CephNFSLister interface {
// List lists all CephNFSes in the indexer.
List(selector labels.Selector) (ret []*v1.CephNFS, err error)
// CephNFSes returns an object that can list and get CephNFSes.
CephNFSes(namespace string) CephNFSNamespaceLister
CephNFSListerExpansion
}
CephNFSLister helps list CephNFSes.
func NewCephNFSLister ¶ added in v1.0.0
func NewCephNFSLister(indexer cache.Indexer) CephNFSLister
NewCephNFSLister returns a new CephNFSLister.
type CephNFSListerExpansion ¶ added in v1.0.0
type CephNFSListerExpansion interface{}
CephNFSListerExpansion allows custom methods to be added to CephNFSLister.
type CephNFSNamespaceLister ¶ added in v1.0.0
type CephNFSNamespaceLister interface {
// List lists all CephNFSes in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephNFS, err error)
// Get retrieves the CephNFS from the indexer for a given namespace and name.
Get(name string) (*v1.CephNFS, error)
CephNFSNamespaceListerExpansion
}
CephNFSNamespaceLister helps list and get CephNFSes.
type CephNFSNamespaceListerExpansion ¶ added in v1.0.0
type CephNFSNamespaceListerExpansion interface{}
CephNFSNamespaceListerExpansion allows custom methods to be added to CephNFSNamespaceLister.
type CephObjectStoreLister ¶
type CephObjectStoreLister interface {
// List lists all CephObjectStores in the indexer.
List(selector labels.Selector) (ret []*v1.CephObjectStore, err error)
// CephObjectStores returns an object that can list and get CephObjectStores.
CephObjectStores(namespace string) CephObjectStoreNamespaceLister
CephObjectStoreListerExpansion
}
CephObjectStoreLister helps list CephObjectStores.
func NewCephObjectStoreLister ¶
func NewCephObjectStoreLister(indexer cache.Indexer) CephObjectStoreLister
NewCephObjectStoreLister returns a new CephObjectStoreLister.
type CephObjectStoreListerExpansion ¶
type CephObjectStoreListerExpansion interface{}
CephObjectStoreListerExpansion allows custom methods to be added to CephObjectStoreLister.
type CephObjectStoreNamespaceLister ¶
type CephObjectStoreNamespaceLister interface {
// List lists all CephObjectStores in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephObjectStore, err error)
// Get retrieves the CephObjectStore from the indexer for a given namespace and name.
Get(name string) (*v1.CephObjectStore, error)
CephObjectStoreNamespaceListerExpansion
}
CephObjectStoreNamespaceLister helps list and get CephObjectStores.
type CephObjectStoreNamespaceListerExpansion ¶
type CephObjectStoreNamespaceListerExpansion interface{}
CephObjectStoreNamespaceListerExpansion allows custom methods to be added to CephObjectStoreNamespaceLister.
type CephObjectStoreUserLister ¶
type CephObjectStoreUserLister interface {
// List lists all CephObjectStoreUsers in the indexer.
List(selector labels.Selector) (ret []*v1.CephObjectStoreUser, err error)
// CephObjectStoreUsers returns an object that can list and get CephObjectStoreUsers.
CephObjectStoreUsers(namespace string) CephObjectStoreUserNamespaceLister
CephObjectStoreUserListerExpansion
}
CephObjectStoreUserLister helps list CephObjectStoreUsers.
func NewCephObjectStoreUserLister ¶
func NewCephObjectStoreUserLister(indexer cache.Indexer) CephObjectStoreUserLister
NewCephObjectStoreUserLister returns a new CephObjectStoreUserLister.
type CephObjectStoreUserListerExpansion ¶
type CephObjectStoreUserListerExpansion interface{}
CephObjectStoreUserListerExpansion allows custom methods to be added to CephObjectStoreUserLister.
type CephObjectStoreUserNamespaceLister ¶
type CephObjectStoreUserNamespaceLister interface {
// List lists all CephObjectStoreUsers in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.CephObjectStoreUser, err error)
// Get retrieves the CephObjectStoreUser from the indexer for a given namespace and name.
Get(name string) (*v1.CephObjectStoreUser, error)
CephObjectStoreUserNamespaceListerExpansion
}
CephObjectStoreUserNamespaceLister helps list and get CephObjectStoreUsers.
type CephObjectStoreUserNamespaceListerExpansion ¶
type CephObjectStoreUserNamespaceListerExpansion interface{}
CephObjectStoreUserNamespaceListerExpansion allows custom methods to be added to CephObjectStoreUserNamespaceLister.