Documentation
¶
Index ¶
- type ClusterLister
- type ClusterListerExpansion
- type ClusterNamespaceLister
- type ClusterNamespaceListerExpansion
- type ISCSILister
- type ISCSIListerExpansion
- type ISCSINamespaceLister
- type ISCSINamespaceListerExpansion
- type ISGWLister
- type ISGWListerExpansion
- type ISGWNamespaceLister
- type ISGWNamespaceListerExpansion
- type NFSLister
- type NFSListerExpansion
- type NFSNamespaceLister
- type NFSNamespaceListerExpansion
- type S3Lister
- type S3ListerExpansion
- type S3NamespaceLister
- type S3NamespaceListerExpansion
- type S3XLister
- type S3XListerExpansion
- type S3XNamespaceLister
- type S3XNamespaceListerExpansion
- type SWIFTLister
- type SWIFTListerExpansion
- type SWIFTNamespaceLister
- type SWIFTNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterLister ¶
type ClusterLister interface {
// List lists all Clusters in the indexer.
List(selector labels.Selector) (ret []*v1.Cluster, err error)
// Clusters returns an object that can list and get Clusters.
Clusters(namespace string) ClusterNamespaceLister
ClusterListerExpansion
}
ClusterLister helps list Clusters.
func NewClusterLister ¶
func NewClusterLister(indexer cache.Indexer) ClusterLister
NewClusterLister returns a new ClusterLister.
type ClusterListerExpansion ¶
type ClusterListerExpansion interface{}
ClusterListerExpansion allows custom methods to be added to ClusterLister.
type ClusterNamespaceLister ¶
type ClusterNamespaceLister interface {
// List lists all Clusters in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.Cluster, err error)
// Get retrieves the Cluster from the indexer for a given namespace and name.
Get(name string) (*v1.Cluster, error)
ClusterNamespaceListerExpansion
}
ClusterNamespaceLister helps list and get Clusters.
type ClusterNamespaceListerExpansion ¶
type ClusterNamespaceListerExpansion interface{}
ClusterNamespaceListerExpansion allows custom methods to be added to ClusterNamespaceLister.
type ISCSILister ¶
type ISCSILister interface {
// List lists all ISCSIs in the indexer.
List(selector labels.Selector) (ret []*v1.ISCSI, err error)
// ISCSIs returns an object that can list and get ISCSIs.
ISCSIs(namespace string) ISCSINamespaceLister
ISCSIListerExpansion
}
ISCSILister helps list ISCSIs.
func NewISCSILister ¶
func NewISCSILister(indexer cache.Indexer) ISCSILister
NewISCSILister returns a new ISCSILister.
type ISCSIListerExpansion ¶
type ISCSIListerExpansion interface{}
ISCSIListerExpansion allows custom methods to be added to ISCSILister.
type ISCSINamespaceLister ¶
type ISCSINamespaceLister interface {
// List lists all ISCSIs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.ISCSI, err error)
// Get retrieves the ISCSI from the indexer for a given namespace and name.
Get(name string) (*v1.ISCSI, error)
ISCSINamespaceListerExpansion
}
ISCSINamespaceLister helps list and get ISCSIs.
type ISCSINamespaceListerExpansion ¶
type ISCSINamespaceListerExpansion interface{}
ISCSINamespaceListerExpansion allows custom methods to be added to ISCSINamespaceLister.
type ISGWLister ¶
type ISGWLister interface {
// List lists all ISGWs in the indexer.
List(selector labels.Selector) (ret []*v1.ISGW, err error)
// ISGWs returns an object that can list and get ISGWs.
ISGWs(namespace string) ISGWNamespaceLister
ISGWListerExpansion
}
ISGWLister helps list ISGWs.
func NewISGWLister ¶
func NewISGWLister(indexer cache.Indexer) ISGWLister
NewISGWLister returns a new ISGWLister.
type ISGWListerExpansion ¶
type ISGWListerExpansion interface{}
ISGWListerExpansion allows custom methods to be added to ISGWLister.
type ISGWNamespaceLister ¶
type ISGWNamespaceLister interface {
// List lists all ISGWs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.ISGW, err error)
// Get retrieves the ISGW from the indexer for a given namespace and name.
Get(name string) (*v1.ISGW, error)
ISGWNamespaceListerExpansion
}
ISGWNamespaceLister helps list and get ISGWs.
type ISGWNamespaceListerExpansion ¶
type ISGWNamespaceListerExpansion interface{}
ISGWNamespaceListerExpansion allows custom methods to be added to ISGWNamespaceLister.
type NFSLister ¶
type NFSLister interface {
// List lists all NFSs in the indexer.
List(selector labels.Selector) (ret []*v1.NFS, err error)
// NFSs returns an object that can list and get NFSs.
NFSs(namespace string) NFSNamespaceLister
NFSListerExpansion
}
NFSLister helps list NFSs.
func NewNFSLister ¶
NewNFSLister returns a new NFSLister.
type NFSListerExpansion ¶
type NFSListerExpansion interface{}
NFSListerExpansion allows custom methods to be added to NFSLister.
type NFSNamespaceLister ¶
type NFSNamespaceLister interface {
// List lists all NFSs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.NFS, err error)
// Get retrieves the NFS from the indexer for a given namespace and name.
Get(name string) (*v1.NFS, error)
NFSNamespaceListerExpansion
}
NFSNamespaceLister helps list and get NFSs.
type NFSNamespaceListerExpansion ¶
type NFSNamespaceListerExpansion interface{}
NFSNamespaceListerExpansion allows custom methods to be added to NFSNamespaceLister.
type S3Lister ¶
type S3Lister interface {
// List lists all S3s in the indexer.
List(selector labels.Selector) (ret []*v1.S3, err error)
// S3s returns an object that can list and get S3s.
S3s(namespace string) S3NamespaceLister
S3ListerExpansion
}
S3Lister helps list S3s.
func NewS3Lister ¶
NewS3Lister returns a new S3Lister.
type S3ListerExpansion ¶
type S3ListerExpansion interface{}
S3ListerExpansion allows custom methods to be added to S3Lister.
type S3NamespaceLister ¶
type S3NamespaceLister interface {
// List lists all S3s in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.S3, err error)
// Get retrieves the S3 from the indexer for a given namespace and name.
Get(name string) (*v1.S3, error)
S3NamespaceListerExpansion
}
S3NamespaceLister helps list and get S3s.
type S3NamespaceListerExpansion ¶
type S3NamespaceListerExpansion interface{}
S3NamespaceListerExpansion allows custom methods to be added to S3NamespaceLister.
type S3XLister ¶
type S3XLister interface {
// List lists all S3Xs in the indexer.
List(selector labels.Selector) (ret []*v1.S3X, err error)
// S3Xs returns an object that can list and get S3Xs.
S3Xs(namespace string) S3XNamespaceLister
S3XListerExpansion
}
S3XLister helps list S3Xs.
func NewS3XLister ¶
NewS3XLister returns a new S3XLister.
type S3XListerExpansion ¶
type S3XListerExpansion interface{}
S3XListerExpansion allows custom methods to be added to S3XLister.
type S3XNamespaceLister ¶
type S3XNamespaceLister interface {
// List lists all S3Xs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.S3X, err error)
// Get retrieves the S3X from the indexer for a given namespace and name.
Get(name string) (*v1.S3X, error)
S3XNamespaceListerExpansion
}
S3XNamespaceLister helps list and get S3Xs.
type S3XNamespaceListerExpansion ¶
type S3XNamespaceListerExpansion interface{}
S3XNamespaceListerExpansion allows custom methods to be added to S3XNamespaceLister.
type SWIFTLister ¶
type SWIFTLister interface {
// List lists all SWIFTs in the indexer.
List(selector labels.Selector) (ret []*v1.SWIFT, err error)
// SWIFTs returns an object that can list and get SWIFTs.
SWIFTs(namespace string) SWIFTNamespaceLister
SWIFTListerExpansion
}
SWIFTLister helps list SWIFTs.
func NewSWIFTLister ¶
func NewSWIFTLister(indexer cache.Indexer) SWIFTLister
NewSWIFTLister returns a new SWIFTLister.
type SWIFTListerExpansion ¶
type SWIFTListerExpansion interface{}
SWIFTListerExpansion allows custom methods to be added to SWIFTLister.
type SWIFTNamespaceLister ¶
type SWIFTNamespaceLister interface {
// List lists all SWIFTs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.SWIFT, err error)
// Get retrieves the SWIFT from the indexer for a given namespace and name.
Get(name string) (*v1.SWIFT, error)
SWIFTNamespaceListerExpansion
}
SWIFTNamespaceLister helps list and get SWIFTs.
type SWIFTNamespaceListerExpansion ¶
type SWIFTNamespaceListerExpansion interface{}
SWIFTNamespaceListerExpansion allows custom methods to be added to SWIFTNamespaceLister.